@@ -7,18 +7,24 @@
 
 #include "mpv_proxy.h"
 #include "mpv_glwidget.h"
+#include "sysutils.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#include <QtGui/private/qtguiglobal_p.h>
+#endif
 
-#include <QtX11Extras/QX11Info>
 #include <QLibrary>
 #include <QPainterPath>
 
 #include <dthememanager.h>
 #include <DApplication>
+#include <QDBusInterface>
 //#include <wayland-client.h>
 //#include "../../window/qplatformnativeinterface.h"
 //qpa/qplatformnativeinterface.h
-#include "compositing_manager.h"
-
 #if defined(_WIN32) && !defined(_WIN32_WCE) && !defined(__SCITECH_SNAP__)
 /* Win32 but not WinCE */
 #   define KHRONOS_APIENTRY __stdcall
@@ -506,22 +512,19 @@ namespace dmr {
         setupIdlePipe();
         setupBlendPipe();
 
-#ifdef _LIBDMR_
-        if(utils::check_wayland_env()){
-            toggleRoundedClip(true);
-        }else{
-            toggleRoundedClip(false);
-        }
-#else
+#ifndef _LIBDMR_
 #ifndef USE_DXCB
         connect(window()->windowHandle(), &QWindow::windowStateChanged, [=]() {
             QWidget* pTopWid = this->topLevelWidget();
             bool rounded = !pTopWid->isFullScreen() && !pTopWid->isMaximized();
-            if(utils::check_wayland_env()){
-                toggleRoundedClip(true);
-            } else {
-                toggleRoundedClip(rounded);
+            // 全屏和最大化下不裁剪圆角
+            m_bDoRoundedClipping = rounded;
+
+            //wayland
+            if(utils::check_wayland_env()) {
+                rounded = true;
             }
+            toggleRoundedClip(rounded);
         });
 #endif
 #endif
@@ -564,7 +567,7 @@ namespace dmr {
 
     void MpvGLWidget::updateMovieFbo()
     {
-        if (!m_bDoRoundedClipping) return;
+        if (!m_bUseCustomFBO) return;
 
         auto desiredSize = size() * qApp->devicePixelRatio();
 
@@ -575,12 +578,23 @@ namespace dmr {
             m_pFbo->release();
             delete m_pFbo;
         }
-        m_pFbo = new QOpenGLFramebufferObject(desiredSize);
+        // 创建 FBO 格式
+        QOpenGLFramebufferObjectFormat format;
+        format.setAttachment(QOpenGLFramebufferObject::CombinedDepthStencil);
+        format.setSamples(0);  // 禁用多重采样，避免与视频渲染冲突
+        format.setTextureTarget(GL_TEXTURE_2D);
+        format.setInternalTextureFormat(GL_RGBA8);  // 使用 8 位 RGBA 格式
+        m_pFbo = new QOpenGLFramebufferObject(desiredSize, format);
+        // 检查 FBO 是否创建成功
+        if (!m_pFbo || !m_pFbo->isValid()) {
+            qWarning() << "Failed to create FBO with size:" << desiredSize;
+            return;
+        }
     }
 
     void MpvGLWidget::updateCornerMasks()
     {
-        if (!utils::check_wayland_env() && !m_bDoRoundedClipping) return;
+        if (!utils::check_wayland_env() && !m_bUseCustomFBO) return;
 
         for (int i = 0; i < 4; i++) {
             QSize sz(RADIUS, RADIUS);
@@ -762,7 +776,7 @@ namespace dmr {
 
         updateMovieFbo();
         updateVbo();
-        if (m_bDoRoundedClipping){
+        if (m_bUseCustomFBO){
             updateVboCorners();
         }
         qInfo() << "GL resize" << nWidth << nHeight;
@@ -771,7 +785,9 @@ namespace dmr {
 
     void MpvGLWidget::toggleRoundedClip(bool bFalse)
     {
-        m_bDoRoundedClipping = bFalse;
+        // 设置圆角时使用自定的FBO，但在全屏和最大化时，通过
+        // m_bDoRoundedClipping 设置是否实际应用圆角
+        m_bUseCustomFBO = bFalse;
         makeCurrent();
         updateMovieFbo();
         update();
@@ -784,7 +800,8 @@ namespace dmr {
         m_bPlaying = false;
         m_bInMiniMode= false;
 
-        m_bDoRoundedClipping=true;
+        m_bUseCustomFBO = true;
+        m_bDoRoundedClipping = true;
         m_pDarkTex = nullptr;
         m_pLightTex = nullptr;
         m_pGlProg = nullptr;
@@ -815,13 +832,24 @@ namespace dmr {
     void MpvGLWidget::paintGL() 
     {
         QOpenGLFunctions *pGLFunction = QOpenGLContext::currentContext()->functions();
+            if (!pGLFunction) {
+        qWarning() << "Failed to get OpenGL functions";
+        return;
+    }
+    
+    // 检查纹理是否有效
+    if (m_pLightTex && !m_pLightTex->isCreated()) {
+        qWarning() << "Light texture not created";
+        return;
+    }
+        
         if (m_bPlaying) {
 
             qreal dpr = qApp->devicePixelRatio();
             QSize scaled = size() * dpr;
             int nFlip = 1;
 
-            if (!m_bDoRoundedClipping) {
+            if (!m_bUseCustomFBO) {
                 mpv_opengl_fbo fbo {
                     static_cast<int>(defaultFramebufferObject()), scaled.width(), scaled.height(), 0
                 };
@@ -834,8 +862,8 @@ namespace dmr {
 
                 m_renderContexRender(m_pRenderCtx, params);
             } else {
-                pGLFunction->glEnable(GL_BLEND);
-                pGLFunction->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+                //pGLFunction->glEnable(GL_BLEND);
+                //pGLFunction->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
                 m_pFbo->bind();
 
@@ -899,9 +927,9 @@ namespace dmr {
                     }
                 }
 
-                pGLFunction->glDisable(GL_BLEND);
+                //pGLFunction->glDisable(GL_BLEND);
             }
-#if 0
+#ifdef __x86_64__
             QWidget *topWidget = topLevelWidget();
             if(topWidget && (topWidget->isFullScreen())) {//全屏状态播放时更新显示进度
                 QString time_text = QTime::currentTime().toString("hh:mm");
@@ -1023,7 +1051,7 @@ namespace dmr {
 
         }
     }
-#if 0
+#ifdef __x86_64__
     void MpvGLWidget::updateMovieProgress(qint64 duration, qint64 pos)
     {
         if (pos > duration)
@@ -1065,9 +1093,7 @@ namespace dmr {
     void MpvGLWidget::initMpvFuns()
     {
         qInfo() << "MpvGLWidget开始initMpvFuns";
-        QString libmpvPath;
-        libmpvPath = CompositingManager::libPath("libmpv.so.");
-        QLibrary mpvLibrary(libmpvPath);
+        QLibrary mpvLibrary(SysUtils::libPath("libmpv.so"));
         m_callback = reinterpret_cast<mpv_render_contextSet_update_callback>(mpvLibrary.resolve("mpv_render_context_set_update_callback"));
         m_context_report = reinterpret_cast<mpv_render_contextReport_swap>(mpvLibrary.resolve("mpv_render_context_report_swap"));
         m_renderContex = reinterpret_cast<mpv_renderContext_free>(mpvLibrary.resolve("mpv_render_context_free"));
