@@ -10,6 +10,7 @@
 #include "compositing_manager.h"
 #include "player_engine.h"
 #include "hwdec_probe.h"
+#include "sysutils.h"
 
 #ifndef _LIBDMR_
 #include "dmr_settings.h"
@@ -23,7 +24,14 @@
 
 #include <xcb/xproto.h>
 #include <xcb/xcb_aux.h>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#include <QtGui/private/qtguiglobal_p.h>
+#endif
+
 #include <QLibrary>
 #include <va/va_x11.h>
 
@@ -139,9 +147,7 @@ void MpvProxy::setDecodeModel(const QVariant &value)
 
 void MpvProxy::initMpvFuns()
 {
-    QString libmpvPath;
-    libmpvPath = CompositingManager::libPath("libmpv.so.");
-    QLibrary mpvLibrary(libmpvPath);
+    QLibrary mpvLibrary(SysUtils::libPath("libmpv.so"));
 
     m_waitEvent = reinterpret_cast<mpv_waitEvent>(mpvLibrary.resolve("mpv_wait_event"));
     m_setOptionString = reinterpret_cast<mpv_set_optionString>(mpvLibrary.resolve("mpv_set_option_string"));
@@ -161,13 +167,11 @@ void MpvProxy::initMpvFuns()
 
 void MpvProxy::initGpuInfoFuns()
 {
-    QString path = CompositingManager::libPath("libgpuinfo.so");  //20220621 add the public API for ready wrapper linglong LD_LIBRARY_PATH path
-    if(!QFileInfo(path).exists()) {
+    if(!SysUtils::libExist("libgpuinfo.so")) {
         m_gpuInfo = NULL;
         return;
     }
-
-    QLibrary mpvLibrary(CompositingManager::libPath("libgpuinfo.so"));
+    QLibrary mpvLibrary(SysUtils::libPath("libgpuinfo.so"));
     m_gpuInfo = reinterpret_cast<void *>(mpvLibrary.resolve("vdp_Iter_decoderInfo"));
 }
 
@@ -203,13 +207,15 @@ void MpvProxy::firstInit()
         if (CompositingManager::get().composited()) {
             m_pMpvGLwidget = new MpvGLWidget(this, m_handle);
             connect(this, &MpvProxy::stateChanged, this, &MpvProxy::slotStateChanged);
-#if 0
-            connect(this, &MpvProxy::elapsedChanged, [ this ]() {//更新opengl显示进度
+#ifdef __x86_64__
+            connect(this, &MpvProxy::elapsedChanged, [ this ]() {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 m_pMpvGLwidget->updateMovieProgress(duration(), elapsed());
+#endif
                 m_pMpvGLwidget->update();
             });
 #endif
-#if defined(USE_DXCB) || defined(_LIBDMR_)
+#if defined(USE_DXCB)
             m_pMpvGLwidget->toggleRoundedClip(false);
 #endif
             QHBoxLayout *pLayout = new QHBoxLayout(this);
@@ -345,67 +351,90 @@ mpv_handle *MpvProxy::mpv_init()
     my_set_property(pHandle, "panscan", 1.0);
 
     if (DecodeMode::SOFTWARE == m_decodeMode) { //1.设置软解
-        my_set_property(m_handle, "hwdec", "no");
+        my_set_property(pHandle, "hwdec", "no");
+#if defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+        if (!CompositingManager::get().hascard()) {
+            qInfo() << "修改音视频同步模式";
+            my_set_property(pHandle, "video-sync", "desync");
+            my_set_property(pHandle, "vo", "x11");
+            m_sInitVo = "x11";
+        }
+#endif
     } else if (DecodeMode::AUTO == m_decodeMode) { //2.设置自动
         //2.1特殊硬件
         //景嘉微显卡目前只支持vo=xv，等日后升级代码需要酌情修改。
         QFileInfo fi("/dev/mwv206_0");
         QFileInfo jmfi("/dev/jmgpu"); //jmgpu
+        QFileInfo X100GPU("/dev/x100gpu");
+        QFileInfo X100VPU("/dev/vxd0");
+        QFileInfo mtfi("/dev/mtgpu.0");
         if (fi.exists() || jmfi.exists()) { //2.1.1景嘉微
             QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
             QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
-            if(sdir.exists()) {
-                 my_set_property(m_handle, "hwdec", "vdpau");
-            } else {
-                 my_set_property(m_handle, "hwdec", "auto");
-            }
-
-            if (!sdir.exists() && jmdir.exists()) {
-                my_set_property(m_handle, "hwdec", "vaapi");
-                my_set_property(m_handle, "vo", "vaapi");
+            if(sdir.exists() && fi.exists()) {
+                my_set_property(pHandle, "hwdec", "vdpau");
+                my_set_property(pHandle, "vo", "vdpau");
+                m_sInitVo = "vdpau";
+            }else if (jmfi.exists() && jmdir.exists()) {
+                my_set_property(pHandle, "hwdec", "vaapi");
+                my_set_property(pHandle, "vo", "vaapi");
                 m_sInitVo = "vaapi";
-            } else {
-                my_set_property(m_handle, "vo", "vdpau,xv,x11");
+            }else {
+                my_set_property(pHandle, "hwdec", "auto");
+                my_set_property(pHandle, "vo", "vdpau,xv,x11");
                 m_sInitVo = "vdpau,xv,x11";
             }
         } else if (QFile::exists("/dev/csmcore")) { //2.1.2中船重工
-            my_set_property(m_handle, "vo", "xv,x11");
-            my_set_property(m_handle, "hwdec", "auto");
+            my_set_property(pHandle, "vo", "xv,x11");
+            my_set_property(pHandle, "hwdec", "auto");
             if (utils::check_wayland_env()) {
                 my_set_property(pHandle, "wid", m_pParentWidget->winId());
             }
             m_sInitVo = "xv,x11";
+        }  else if (X100GPU.exists() && X100VPU.exists()) {
+            my_set_property(m_handle, "hwdec", "ftomx-copy");
+            my_set_property(m_handle, "vo", "gpu");
         } else if (CompositingManager::get().isOnlySoftDecode()) {//2.1.3 鲲鹏920 || 曙光+英伟达 || 浪潮
-            my_set_property(m_handle, "hwdec", "no");
+            my_set_property(pHandle, "hwdec", "no");
         } else { //2.2非特殊硬件
-            my_set_property(m_handle, "hwdec", "auto");
+            my_set_property(pHandle, "hwdec", "auto");
         }
 
 #if defined (__mips__)
         if (!CompositingManager::get().hascard()) {
             qInfo() << "修改音视频同步模式";
-            my_set_property(m_handle, "video-sync", "desync");
+            my_set_property(pHandle, "video-sync", "desync");
         }
-        my_set_property(m_handle, "vo", "vdpau,gpu,x11");
-        my_set_property(m_handle, "ao", "alsa");
+        my_set_property(pHandle, "vo", "vdpau,gpu,x11");
+        my_set_property(pHandle, "ao", "alsa");
         m_sInitVo = "vdpau,gpu,x11";
 #elif defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
         if (!CompositingManager::get().hascard()) {
             qInfo() << "修改音视频同步模式";
-            my_set_property(m_handle, "video-sync", "desync");
+            my_set_property(pHandle, "video-sync", "desync");
         }
-        if (!fi.exists() && !jmfi.exists()) {
-            my_set_property(m_handle, "vo", "gpu,x11");
-            m_sInitVo = "gpu,x11";
+        if (!fi.exists() && !jmfi.exists() && !mtfi.exists()) {
+            if(CompositingManager::get().property("directRendering").toBool()) {
+                my_set_property(pHandle, "vo", "gpu,x11");
+                m_sInitVo = "gpu,x11";
+            } else {
+                my_set_property(pHandle, "vo", "x11");
+                m_sInitVo = "x11";
+            }
         }
 #elif defined (__sw_64__)
         //Synchronously modify the video output of the SW platform vdpau(powered by zhangfl)
-        my_set_property(m_handle, "vo", "vdpau,gpu,x11");
-        m_sInitVo = "vdpau,gpu,x11";
+        my_set_property(pHandle, "vo", "gpu,x11");
+        m_sInitVo = "gpu,x11";
 #elif defined (__aarch64__)
         if (!fi.exists() && !jmfi.exists()) { //2.1.1景嘉微
-            my_set_property(m_handle, "vo", "gpu,xv,x11");
-            m_sInitVo = "gpu,xv,x11";
+            my_set_property(pHandle, "vo", "x11,gpu,xv");
+            m_sInitVo = "x11,gpu,xv";
+        }
+        if (CompositingManager::get().isSpecialControls()) {
+            my_set_property(pHandle, "hwdec", "vaapi");
+            my_set_property(pHandle, "vo", "vaapi");
+            m_sInitVo = "vaapi";
         }
 #else
         //去除9200显卡适配
@@ -420,30 +449,120 @@ mpv_handle *MpvProxy::mpv_init()
         }
         //TODO(xxxxpengfei)：暂未处理intel集显情况
         if (CompositingManager::get().isZXIntgraphics() && !jmflag) {
-            my_set_property(m_handle, "vo", "gpu");
-        }
-#endif
-    } else { //3.设置硬解
-        QFileInfo fi("/dev/mwv206_0");
-		QFileInfo jmfi("/dev/jmgpu");
-        if (fi.exists()) { //2.1.1景嘉微
-            QDir sdir(CompositingManager::libPath("mwv206")); //判断是否安装核外驱动
-			QDir jmdir(CompositingManager::libPath("mwv207"));
-            if(sdir.exists()) {
-                 my_set_property(m_handle, "hwdec", "vdpau");
-            } else {
-                 my_set_property(m_handle, "hwdec", "auto");
-            }
-            if (!sdir.exists() && jmdir.exists()) {
-                my_set_property(m_handle, "hwdec", "vaapi");
-                my_set_property(m_handle, "vo", "vaapi");
+            QProcess process;
+            QStringList options;
+            options << "-c" << QString("apt policy cx4-linux-graphics-driver-dri | sed -n \'2p\'");
+            process.start("/bin/bash", options);
+            process.waitForFinished();
+            process.waitForReadyRead();
+
+            QString comStr = process.readAllStandardOutput();
+            comStr = comStr.right(3).left(2);
+            int version = comStr.toInt();
+            if (version >= 10) {
+                my_set_property(pHandle, "vo", "vaapi");
+                my_set_property(pHandle, "hwdec", "vaapi");
                 m_sInitVo = "vaapi";
             } else {
-                my_set_property(m_handle, "vo", "vdpau,xv,x11");
+                my_set_property(pHandle, "vo", "gpu");
+                m_sInitVo = "gpu";
+            }
+        }
+#endif
+        if (utils::check_wayland_env()) {
+            qInfo() << "V25 set ao auto";
+            my_set_property(pHandle, "ao", "auto");
+        }
+
+        if (QFile::exists("/sys/bus/pci/drivers/ljmcore")) {
+            my_set_property(pHandle, "vo", "vaapi");
+            my_set_property(pHandle, "hwdec", "vaapi");
+            m_sInitVo = "vaapi";
+        }
+
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(pHandle, "hwdec", "no");
+            my_set_property(pHandle, "vo", "x11");
+            my_set_property(pHandle, "video-sync", "desync");
+            my_set_property(pHandle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
+
+        QDir innodir("/sys/bus/platform/drivers/inno-codec");
+        if ( innodir.exists()) {
+            my_set_property(pHandle, "vo", "gpu,x11");
+            m_sInitVo = "gpu,x11";
+        }
+    } else { //3.设置硬解
+        QFileInfo fi("/dev/mwv206_0");
+        QFileInfo jmfi("/dev/jmgpu");
+        QFileInfo X100GPU("/dev/x100gpu");
+        QFileInfo X100VPU("/dev/vxd0");
+        if (fi.exists() || jmfi.exists()) { //2.1.1景嘉微
+            QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
+            QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
+            if(sdir.exists() && fi.exists()) {
+                my_set_property(pHandle, "hwdec", "vdpau");
+                my_set_property(pHandle, "vo", "vdpau");
+                m_sInitVo = "vdpau";
+            }else if (jmfi.exists() && jmdir.exists()) {
+                my_set_property(pHandle, "hwdec", "vaapi");
+                my_set_property(pHandle, "vo", "vaapi");
+                m_sInitVo = "vaapi";
+            } else {
+                my_set_property(pHandle, "hwdec", "auto");
+                my_set_property(pHandle, "vo", "vdpau,xv,x11");
                 m_sInitVo = "vdpau,xv,x11";
             }
+        } else if (X100GPU.exists() && X100VPU.exists()) {
+            my_set_property(m_handle, "hwdec", "ftomx-copy");
+            my_set_property(m_handle, "vo", "gpu");
         } else {
-            my_set_property(m_handle, "hwdec", "auto");
+            my_set_property(pHandle, "hwdec", "auto");
+        }
+
+#if defined (__sw_64__)
+        //Synchronously modify the video output of the SW platform vdpau(powered by zhangfl)
+        my_set_property(pHandle, "vo", "gpu,x11");
+        m_sInitVo = "gpu,x11";
+#elif defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+        if (!CompositingManager::get().hascard()) {
+            qInfo() << "修改音视频同步模式";
+            my_set_property(pHandle, "video-sync", "desync");
+        }
+        if (!fi.exists() && !jmfi.exists()) {
+            if(CompositingManager::get().property("directRendering").toBool()) {
+                my_set_property(pHandle, "vo", "gpu,x11");
+                m_sInitVo = "gpu,x11";
+            } else {
+                my_set_property(pHandle, "vo", "x11");
+                m_sInitVo = "x11";
+            }
+        }
+#endif
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(pHandle, "hwdec", "no");
+            my_set_property(pHandle, "vo", "x11");
+            my_set_property(pHandle, "video-sync", "desync");
+            my_set_property(pHandle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
+
+        QDir innodir("/sys/bus/platform/drivers/inno-codec");
+        if ( innodir.exists()) {
+            my_set_property(pHandle, "vo", "gpu,x11");
+            m_sInitVo = "gpu,x11";
+        }
+        if (QFile::exists("/sys/bus/pci/drivers/ljmcore")) {
+            my_set_property(pHandle, "vo", "vaapi");
+            my_set_property(pHandle, "hwdec", "vaapi");
+            m_sInitVo = "vaapi";
+        }
+
+        if (CompositingManager::get().isSpecialControls()) {
+            my_set_property(pHandle, "hwdec", "vaapi");
+            my_set_property(pHandle, "vo", "vaapi");
+            m_sInitVo = "vaapi";
         }
     }
 
@@ -456,13 +575,18 @@ mpv_handle *MpvProxy::mpv_init()
         qInfo() << "-------- __mips__hwdec____________";
         m_sInitVo = "opengl-cb";
 #else
-        my_set_property(pHandle, "vo", "libmpv,opengl-cb");
+        my_set_property(pHandle, "vo", "libmpv");
         my_set_property(pHandle, "vd-lavc-dr", "no");
         my_set_property(pHandle, "gpu-sw", "on");
-        m_sInitVo = "libmpv,opengl-cb";
+        m_sInitVo = "libmpv";
 #endif
     } else {
-        my_set_property(m_handle, "wid", m_pParentWidget->winId());
+        my_set_property(pHandle, "wid", m_pParentWidget->winId());
+    }
+
+
+    if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+        my_set_property(pHandle, "update-on-pause", "yes");
     }
 
     qInfo() << __func__ << "vo:" << my_get_property(pHandle, "vo").toString();
@@ -542,6 +666,23 @@ mpv_handle *MpvProxy::mpv_init()
 
     //设置hwdec和vo配置
     CompositingManager::get().getMpvConfig(m_pConfig);
+#ifndef _LIBDMR_
+    if (Settings::get().settings()->getOption(QString("base.decode.select")).toInt() == 3) {
+        int decodeIndex = Settings::get().settings()->getOption(QString("base.decode.Decodemode")).toInt();
+        auto decodeModeOpt = Settings::get().settings()->option("base.decode.Decodemode");
+        QString decodeMode = decodeModeOpt.data()->data("items").toStringList()[decodeIndex];
+        decodeMode = decodeMode.isEmpty() ? "auto" : decodeMode;
+        m_pConfig->insert("hwdec", decodeMode);
+
+        if (!CompositingManager::get().composited()) {
+            int voIndex = Settings::get().settings()->getOption(QString("base.decode.Videoout")).toInt();
+            auto voOpt = Settings::get().settings()->option("base.decode.Videoout");
+            QString voMode = voOpt.data()->data("items").toStringList()[voIndex];
+            voMode = voMode.isEmpty() ? "auto" : voMode;
+            m_pConfig->insert("vo", voMode);
+        }
+    }
+#endif
     QMap<QString, QString>::iterator iter = m_pConfig->begin();
     qInfo() << __func__ << "First set mpv propertys!!";
     while (iter != m_pConfig->end()) {
@@ -608,8 +749,55 @@ const PlayingMovieInfo &MpvProxy::playingMovieInfo()
     return m_movieInfo;
 }
 
+/**
+ * @return 返回当前设备是否为特殊的HW设备类型,用于进行软/硬解码支持的判断
+ */
+bool isSpecialHWHardware()
+{
+    enum HWDevice { Unknown, IsHWDev, NotHWDev };
+    static HWDevice s_DevType = Unknown;
+
+    if (Unknown == s_DevType) {
+        s_DevType = NotHWDev;
+
+        QProcess process;
+        process.start("dmidecode", {"-s", "system-product-name"});
+        process.waitForFinished(100);
+        QString info = process.readAllStandardOutput();
+        if (info.isEmpty()) {
+            return false;
+        }
+
+        QStringList specilDev{"KLVV", "KLVU", "PGUV", "PGUW", "L540", "W585"};
+        for (const QString &dev : specilDev) {
+            if (info.contains(dev)) {
+                s_DevType = IsHWDev;
+                break;
+            }
+        }
+
+        if (NotHWDev == s_DevType) {
+            // dmidecode | grep -i “String 4”中的值来区分主板类型,PWC30表示PanguW（也就是W525）
+            process.start("bash", {"-c", "dmidecode -t 11 | grep -i \"String 4\""});
+            process.waitForFinished(100);
+            info = process.readAll();
+            if (info.contains("PWC30") || info.contains("PGUX")) {
+                s_DevType = IsHWDev;
+            }
+        }
+
+        qInfo() << QString("Detect HW device, current type is: %1").arg((IsHWDev == s_DevType) ? "true" : "false");
+    }
+
+    return bool(s_DevType == IsHWDev);
+}
+
 bool MpvProxy::isSurportHardWareDecode(const QString sDecodeName, const int &nVideoWidth, const int &nVideoHeight)
 {
+    if (utils::check_wayland_env() && isSpecialHWHardware()) {
+        return true;
+    }
+
     bool isHardWare = true;//未安装探测工具默认支持硬解
     decoder_profile decoderValue = decoder_profile::UN_KNOW; //初始化支持解码值
     decoderValue = (decoder_profile)getDecodeProbeValue(sDecodeName); //根据视频格式获取解码值
@@ -726,6 +914,7 @@ void MpvProxy::handle_mpv_events()
             qInfo() << QString("rotate metadata: dec %1, out %2")
                     .arg(my_get_property(m_handle, "video-dec-params/rotate").toInt())
                     .arg(my_get_property(m_handle, "video-params/rotate").toInt());
+            m_bLoadMedia = false;
             break;
         }
         case MPV_EVENT_VIDEO_RECONFIG: {
@@ -745,6 +934,7 @@ void MpvProxy::handle_mpv_events()
                     "reason " << ev_ef->reason;
 
             setState(PlayState::Stopped);
+            m_bLoadMedia = false;
             break;
         }
 
@@ -1092,24 +1282,37 @@ void MpvProxy::refreshDecode()
             auto codec = currentInfo.mi.videoCodec();
             auto name = _file.fileName();
             isSoftCodec = codec.toLower().contains("mpeg2video") || codec.toLower().contains("wmv") || name.toLower().contains("wmv");
-#if !defined(_loongarch) && !defined(__loongarch__) && !defined(__loongarch64)
             //去除9200显卡适配
             QFileInfo jmfi("/dev/jmgpu");
+            QFileInfo fi("/dev/mwv206_0");
             bool jmflag =false;
-            if (jmfi.exists()) {
+            if (jmfi.exists() || fi.exists()) {
                 QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
                 if(jmdir.exists())
                 {
                     jmflag=true;
                 }
+                isSoftCodec = codec.toLower().contains("mpeg4") ? true : isSoftCodec;
             }
+            QFileInfo X100GPU("/dev/x100gpu");
+            bool x100flag =false;
+            if (X100GPU.exists()) {
+                x100flag = true;
+            }
+#if !defined(_loongarch) && !defined(__loongarch__) && !defined(__loongarch64)
             //探测硬解码
-            if(!isSoftCodec && !CompositingManager::get().isZXIntgraphics() && !jmflag) {
+            if(!isSoftCodec && !CompositingManager::get().isZXIntgraphics() && !jmflag && !x100flag) {
                 isSoftCodec = !isSurportHardWareDecode(codec, currentInfo.mi.width, currentInfo.mi.height);
             }
 #endif
+            if(utils::check_wayland_env()){
+                PlaylistModel *playMode = dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist();
+                QVariant varPixfmt = playMode->property(currentInfo.mi.filePath.toUtf8());
+                if(varPixfmt.isValid() && varPixfmt.toInt() == AV_PIX_FMT_YUV444P) {
+                    isSoftCodec = true;
+                }
+            }
         }
-
         if (isSoftCodec) {
             qInfo() << "my_set_property hwdec no";
             my_set_property(m_handle, "hwdec", "no");
@@ -1117,32 +1320,59 @@ void MpvProxy::refreshDecode()
             //2.2.1 特殊硬件
             QFileInfo fi("/dev/mwv206_0"); //2.2.1.1 景嘉微
             QFileInfo jmfi("/dev/jmgpu");
+            QFileInfo X100GPU("/dev/x100gpu");
+            QFileInfo X100VPU("/dev/vxd0");
             if (fi.exists() || jmfi.exists()) {
-                QDir sdir(CompositingManager::libPath("mwv206")); //判断是否安装核外驱动
-				QDir jmdir(CompositingManager::libPath("mwv207"));
-                if(sdir.exists())
-                {
-                     my_set_property(m_handle, "hwdec", "vdpau");
-                }else {
-                     my_set_property(m_handle, "hwdec", "auto");
-                }
-                if (!sdir.exists() && jmdir.exists()) {
-                    my_set_property(m_handle, "hwdec", "vaapi");
+                PlayItemInfo currentInfo = dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist()->currentInfo();
+                auto codec = currentInfo.mi.videoCodec();
+                if (codec.toLower().contains("mpeg2") || codec.toLower().contains("mpeg4")) {
+                    my_set_property(m_handle, "hwdec", "no");
+                } else {
+                    QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
+                    QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
+                    if(sdir.exists() && fi.exists()) {
+                        my_set_property(m_handle, "hwdec", "vdpau");
+                        my_set_property(m_handle, "vo", "vdpau");
+                    }else if (jmfi.exists() && jmdir.exists()) {
+                        my_set_property(m_handle, "hwdec", "vaapi");
+                        my_set_property(m_handle, "vo", "vaapi");
+                    }else {
+                        my_set_property(m_handle, "hwdec", "auto");
+                    }
                 }
+            } else if (X100GPU.exists() && X100VPU.exists()) {
+                my_set_property(m_handle, "hwdec", "ftomx-copy");
+                my_set_property(m_handle, "vo", "gpu");
             } else if (CompositingManager::get().isOnlySoftDecode()) { //2.2.1.2 鲲鹏920 || 曙光+英伟达 || 浪潮
                 my_set_property(m_handle, "hwdec", "no");
+            } else if (CompositingManager::get().isSpecialControls()) {
+                my_set_property(m_handle, "hwdec", "vaapi");
             } else { //2.2.2 非特殊硬件 + 非特殊格式
                  my_set_property(m_handle, "hwdec","auto");
                 //bIsCanHwDec ? my_set_property(m_handle, "hwdec", canHwTypes.join(',')) : my_set_property(m_handle, "hwdec", "no");
             }
         }
+
+        if (QFile::exists("/sys/bus/pci/drivers/ljmcore")) {
+            my_set_property(m_handle, "hwdec", "vaapi");
+        }
+
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(m_handle, "hwdec", "no");
+            my_set_property(m_handle, "vo", "x11");
+            my_set_property(m_handle, "video-sync", "desync");
+            my_set_property(m_handle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
     } else { //3.设置硬解
 #ifndef _LIBDMR_
 
-#if defined (__aarch64__) || defined (__sw_64__)
+#if defined (__aarch64__)
         // 鲲鹏920 || 曙光+英伟达 || 浪潮
         if (!CompositingManager::get().hascard() || CompositingManager::get().isOnlySoftDecode()) {
             my_set_property(m_handle, "hwdec", "no");
+        } else if (CompositingManager::get().isSpecialControls()) {
+            my_set_property(m_handle, "hwdec", "vaapi");
         } else {
             my_set_property(m_handle, "hwdec","auto");
         }
@@ -1164,22 +1394,65 @@ void MpvProxy::refreshDecode()
 #endif
         QFileInfo fi("/dev/mwv206_0"); //2.2.1.1 景嘉微
         QFileInfo jmfi("/dev/jmgpu");
+        QFileInfo X100GPU("/dev/x100gpu");
+        QFileInfo X100VPU("/dev/vxd0");
         if (fi.exists() || jmfi.exists()) {
-            QDir sdir(CompositingManager::libPath("mwv206")); //判断是否安装核外驱动
-			QDir jmdir(CompositingManager::libPath("mwv207"));
-            if(sdir.exists())
-            {
-                 my_set_property(m_handle, "hwdec", "vdpau");
-            } else {
-                 my_set_property(m_handle, "hwdec", "auto");
-            }
-            if (!sdir.exists() && jmdir.exists()) {
+            QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
+            QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
+            if(sdir.exists() && fi.exists()) {
+                my_set_property(m_handle, "hwdec", "vdpau");
+                my_set_property(m_handle, "vo", "vdpau");
+            }else if (jmfi.exists() && jmdir.exists()) {
                 my_set_property(m_handle, "hwdec", "vaapi");
+                my_set_property(m_handle, "vo", "vaapi");
+            }else {
+                my_set_property(m_handle, "hwdec", "auto");
+            }
+        } else if (X100GPU.exists() && X100VPU.exists()) {
+            my_set_property(m_handle, "hwdec", "ftomx-copy");
+            my_set_property(m_handle, "vo", "gpu");
+        }
+
+        if (QFile::exists("/sys/bus/pci/drivers/ljmcore")) {
+            my_set_property(m_handle, "hwdec", "vaapi");
+        }
+
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(m_handle, "hwdec", "no");
+            my_set_property(m_handle, "vo", "x11");
+            my_set_property(m_handle, "video-sync", "desync");
+            my_set_property(m_handle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
+
+        if(utils::check_wayland_env()){
+            PlaylistModel *playMode = dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist();
+            PlayItemInfo currentInfo = playMode->currentInfo();
+            QVariant varPixfmt = playMode->property(currentInfo.mi.filePath.toUtf8());
+            if(varPixfmt.isValid() && varPixfmt.toInt() == AV_PIX_FMT_YUV444P) {
+                my_set_property(m_handle, "hwdec","no");
             }
         }
 
         //play.conf
         CompositingManager::get().getMpvConfig(m_pConfig);
+#ifndef _LIBDMR_
+        if (Settings::get().settings()->getOption(QString("base.decode.select")).toInt() == 3) {
+            int decodeIndex = Settings::get().settings()->getOption(QString("base.decode.Decodemode")).toInt();
+            auto decodeModeOpt = Settings::get().settings()->option("base.decode.Decodemode");
+            QString decodeMode = decodeModeOpt.data()->data("items").toStringList()[decodeIndex];
+            decodeMode = decodeMode.isEmpty() ? "auto" : decodeMode;
+            m_pConfig->insert("hwdec", decodeMode);
+
+            if (!CompositingManager::get().composited()) {
+                int voIndex = Settings::get().settings()->getOption(QString("base.decode.Videoout")).toInt();
+                auto voOpt = Settings::get().settings()->option("base.Customize.Videoout");
+                QString voMode = voOpt.data()->data("items").toStringList()[voIndex];
+                voMode = voMode.isEmpty() ? "auto" : voMode;
+                m_pConfig->insert("vo", voMode);
+            }
+        }
+#endif
         QMap<QString, QString>::iterator iter = m_pConfig->begin();
         while (iter != m_pConfig->end()) {
             if (iter.key().contains(QString("hwdec"))) {
@@ -1203,6 +1476,7 @@ void MpvProxy::initMember()
     m_bPendingSeek = false;
     m_bPolling = false;
     m_bConnectStateChange = false;
+    m_bLoadMedia = false;
     m_bPauseOnStart = false;
     m_bIsJingJia = false;
     m_bInited = false;
@@ -1234,11 +1508,18 @@ void MpvProxy::initMember()
 
 void MpvProxy::play()
 {
+    if(m_bLoadMedia) {
+        QTimer::singleShot(5000, [=](){ //超时5s恢复状态，视频加载成功后也会重置状态，正常播放状态下不会进入此函数
+            m_bLoadMedia = false;
+        });
+        return;
+    }
     bool bRawFormat = false;
     QList<QVariant> listArgs = { "loadfile" };
     QStringList listOpts = { };
     PlayerEngine* pEngine = nullptr;
     bool bAudio = false;
+    m_bLoadMedia = true;
 
     if (!m_bInited) {
         firstInit();
@@ -1281,27 +1562,6 @@ void MpvProxy::play()
     if (!_dvdDevice.isEmpty()) {
         listOpts << QString("dvd-device=%1").arg(_dvdDevice);
     }
-
-//注：m_bHwaccelAuto 好像是废弃了,初始化为false,此处未执行
-//    if (m_bHwaccelAuto && m_bLastIsSpecficFormat) {
-//        if (!m_bIsJingJia || !utils::check_wayland_env()) {
-//            // hwdec could be disabled by some codecs, so we need to re-enable it
-//            my_set_property(m_handle, "hwdec", "auto");
-//#if defined (__mips__) || defined (__aarch64__) || defined (__sw_64__)
-//            if (!CompositingManager::get().hascard() || CompositingManager::get().isOnlySoftDecode()) {
-//                my_set_property(m_handle, "hwdec", "no");
-//            }
-//#endif
-//        }
-//    }
-//#else
-//    if (m_bHwaccelAuto) {
-//        if (CompositingManager::get().isOnlySoftDecode()) {
-//            my_set_property(m_handle, "hwdec", "no");
-//        } else {
-//            my_set_property(m_handle, "hwdec", "auto");
-//        }
-//    }
 #endif
 
     //刷新解码模式
@@ -1320,12 +1580,12 @@ void MpvProxy::play()
     if (listOpts.size()) {
         listArgs << "replace";
         if (MPV_CLIENT_API_VERSION >= MPV_MAKE_VERSION(2,3)) {
-             listArgs << "-1";
+            listArgs << "-1";
         }
         listArgs << listOpts.join(',');
     }
 
-    qInfo() << listArgs;
+    qInfo()<<"" << listArgs << listOpts;
 
     //设置播放参数
     QMap<QString, QString>::iterator iter = m_pConfig->begin();
@@ -1349,7 +1609,11 @@ void MpvProxy::play()
             if (!QFile::exists(sub)) {
                 MovieConfiguration::get().removeFromListUrl(_file, ConfigKnownKey::ExternalSubs, sub);
             } else {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 loadSubtitle(sub);
+#else
+                loadSubtitle(QFileInfo(sub));
+#endif
             }
         }
 
@@ -1574,9 +1838,15 @@ QImage MpvProxy::takeOneScreenshot()
         img.bits();
         int rotationdegree = videoRotation();
         if (rotationdegree && (CompositingManager::get().composited() || bNeedRotate)) {      //只有opengl窗口需要自己旋转
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             QMatrix matrix;
             matrix.rotate(rotationdegree);
             img = QPixmap::fromImage(img).transformed(matrix, Qt::SmoothTransformation).toImage();
+#else
+            QTransform transform;
+            transform.rotate(rotationdegree);
+            img = QPixmap::fromImage(img).transformed(transform, Qt::SmoothTransformation).toImage();
+#endif
         }
         m_freeNodecontents(&res);
         return img;
