@@ -3,10 +3,6 @@
 <TS version="2.1" language="ro">
 <context>
     <name>MircastShowWidget</name>
-    <message>
-        <source>Exit Miracast</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Projecting... 
 Please do not exit the Movie app during the process.</source>
@@ -16,6 +12,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Display device</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Exit Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MircastWidget</name>
@@ -270,6 +270,27 @@ Please do not exit the Movie app during the process.</source>
         <source>Software decoding</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Customize</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Decode mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The custom decoding method needs to be restarted before it can take effect,
+and whether to restart it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering engine</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UrlDialog</name>
@@ -324,6 +345,34 @@ Please do not exit the Movie app during the process.</source>
         <source>Open CD/DVD</source>
         <translation>Deschide CD/DVD</translation>
     </message>
+    <message>
+        <source>Mini Mode</source>
+        <translation>Mod Mini</translation>
+    </message>
+    <message>
+        <source>Play Mode</source>
+        <translation>Mod redare</translation>
+    </message>
+    <message>
+        <source>Order Play</source>
+        <translation>Redare în ordine</translation>
+    </message>
+    <message>
+        <source>Shuffle Play</source>
+        <translation>Redare aleatorie</translation>
+    </message>
+    <message>
+        <source>Single Play</source>
+        <translation>Redă un singur fisier</translation>
+    </message>
+    <message>
+        <source>Single Loop</source>
+        <translation>Redă video-ul fără pauză</translation>
+    </message>
+    <message>
+        <source>List Loop</source>
+        <translation>Redă lista fără pauză</translation>
+    </message>
     <message>
         <source>Frame</source>
         <translation>Cadru</translation>
@@ -372,10 +421,18 @@ Please do not exit the Movie app during the process.</source>
         <source>Load</source>
         <translation>Încarcare</translation>
     </message>
+    <message>
+        <source>Online Search</source>
+        <translation>Căutare online</translation>
+    </message>
     <message>
         <source>Select</source>
         <translation>Selectare</translation>
     </message>
+    <message>
+        <source>Hide</source>
+        <translation>Ascundere</translation>
+    </message>
     <message>
         <source>Encodings</source>
         <translation>Compresie</translation>
@@ -384,10 +441,22 @@ Please do not exit the Movie app during the process.</source>
         <source>Screenshot</source>
         <translation>Captură  ecran</translation>
     </message>
+    <message>
+        <source>Film Screenshot</source>
+        <translation>Captură ecran video</translation>
+    </message>
+    <message>
+        <source>Burst Shooting</source>
+        <translation>Captură ecran rafală</translation>
+    </message>
     <message>
         <source>Playlist</source>
         <translation>Lista de redare</translation>
     </message>
+    <message>
+        <source>Film Info</source>
+        <translation>Informație video</translation>
+    </message>
     <message>
         <source>Delete from playlist</source>
         <translation type="unfinished"></translation>
@@ -396,10 +465,22 @@ Please do not exit the Movie app during the process.</source>
         <source>Display in file manager</source>
         <translation>Deschide în managerul de fișiere</translation>
     </message>
+    <message>
+        <source>Next Frame</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previous Frame</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Open screenshot folder</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Playback Speed</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>0.5x</source>
         <translation type="unfinished"></translation>
@@ -420,70 +501,6 @@ Please do not exit the Movie app during the process.</source>
         <source>2.0x</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Play</source>
-        <translation type="unfinished">Redare</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation type="unfinished">Precedent</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation type="unfinished">Următorul</translation>
-    </message>
-    <message>
-        <source>Order play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Shuffle play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single loop</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>List loop</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation type="unfinished">Cadrul următor</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation type="unfinished">Cadrul trecut</translation>
-    </message>
-    <message>
-        <source>Playback speed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Mini mode</source>
-        <translation type="unfinished">Minimalizare fereastră</translation>
-    </message>
-    <message>
-        <source>Online search</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Film screenshot</source>
-        <translation type="unfinished">Captură ecran video</translation>
-    </message>
-    <message>
-        <source>Burst shooting</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>dmr::BurstScreenshotsDialog</name>
@@ -566,6 +583,14 @@ Please do not exit the Movie app during the process.</source>
         <source>Speed: %1x</source>
         <translation>Viteză: %1x</translation>
     </message>
+    <message>
+        <source>View</source>
+        <translation>Aspect</translation>
+    </message>
+    <message>
+        <source>Saved to</source>
+        <translation>Salvare la</translation>
+    </message>
     <message>
         <source>The screenshot is saved</source>
         <translation>Salvare captura de ecran efectuată</translation>
@@ -594,6 +619,10 @@ Please do not exit the Movie app during the process.</source>
         <source>No video file found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation>Captură ecran video</translation>
+    </message>
     <message>
         <source>Taking the screenshots, please wait...</source>
         <translation type="unfinished"></translation>
@@ -675,12 +704,13 @@ Please do not exit the Movie app during the process.</source>
         <source>Miracast disconnected</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>dmr::MessageWindow</name>
     <message>
-        <source>View</source>
-        <translation type="obsolete">Aspect</translation>
+        <source>Cancel</source>
+        <translation type="unfinished">Anulare</translation>
+    </message>
+    <message>
+        <source>Restart</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -716,6 +746,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Duration</source>
         <translation>Durată</translation>
     </message>
+    <message>
+        <source>Type</source>
+        <translation>Tip</translation>
+    </message>
     <message>
         <source>Size</source>
         <translation>Dimensiune</translation>
@@ -796,14 +830,6 @@ Please do not exit the Movie app during the process.</source>
         <source>%1 bps</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Name</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>dmr::MpvProxy</name>
@@ -879,6 +905,18 @@ Please do not exit the Movie app during the process.</source>
         <comment>All (*)</comment>
         <translation type="unfinished">Subtitrare (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
     </message>
+    <message>
+        <source>View</source>
+        <translation type="unfinished">Aspect</translation>
+    </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation type="unfinished">Captură ecran video</translation>
+    </message>
+    <message>
+        <source>Saved to</source>
+        <translation type="unfinished">Salvare la</translation>
+    </message>
     <message>
         <source>The screenshot is saved</source>
         <translation type="unfinished">Salvare captura de ecran efectuată</translation>
@@ -983,12 +1021,13 @@ Please do not exit the Movie app during the process.</source>
         <source>Miracast disconnected</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>dmr::Platform_MessageWindow</name>
     <message>
-        <source>View</source>
-        <translation type="obsolete">Aspect</translation>
+        <source>Cancel</source>
+        <translation type="unfinished">Anulare</translation>
+    </message>
+    <message>
+        <source>Restart</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1004,6 +1043,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Playlist</source>
         <translation type="unfinished">Lista de redare</translation>
     </message>
+    <message>
+        <source>Empty</source>
+        <translation type="unfinished">Gol</translation>
+    </message>
     <message>
         <source>%1 videos</source>
         <translation type="unfinished"></translation>
@@ -1016,21 +1059,17 @@ Please do not exit the Movie app during the process.</source>
         <translation type="unfinished">Redare/Pauză</translation>
     </message>
     <message>
-        <source>15s backward</source>
-        <translation type="unfinished">0.5s înapoi {15s?}</translation>
+        <source>Previous</source>
+        <translation type="unfinished">Precedent</translation>
     </message>
     <message>
-        <source>15s forward</source>
-        <translation type="unfinished">0.5s înainte {15s?}</translation>
+        <source>Next</source>
+        <translation type="unfinished">Următorul</translation>
     </message>
     <message>
         <source>Fullscreen</source>
         <translation type="unfinished">Redare ecran complet</translation>
     </message>
-    <message>
-        <source>Miracast</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Playlist</source>
         <translation type="unfinished">Lista de redare</translation>
@@ -1047,6 +1086,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Play</source>
         <translation type="unfinished">Redare</translation>
     </message>
+    <message>
+        <source>Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::PlayItemWidget</name>
@@ -1065,6 +1108,10 @@ Please do not exit the Movie app during the process.</source>
         <source>%1 videos</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Empty</source>
+        <translation>Gol</translation>
+    </message>
 </context>
 <context>
     <name>dmr::Settings</name>
@@ -1111,6 +1158,14 @@ Please do not exit the Movie app during the process.</source>
         <source>Play</source>
         <translation>Redare</translation>
     </message>
+    <message>
+        <source>Previous</source>
+        <translation>Precedent</translation>
+    </message>
+    <message>
+        <source>Next</source>
+        <translation>Următorul</translation>
+    </message>
     <message>
         <source>Playlist</source>
         <translation>Lista de redare</translation>
@@ -1131,17 +1186,20 @@ Please do not exit the Movie app during the process.</source>
         <source>Pause</source>
         <translation>Pauză</translation>
     </message>
-    <message>
-        <source>15s backward</source>
-        <translation type="unfinished">0.5s înapoi {15s?}</translation>
-    </message>
-    <message>
-        <source>15s forward</source>
-        <translation type="unfinished">0.5s înainte {15s?}</translation>
-    </message>
     <message>
         <source>Miracast</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Volume</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::VolumeButton</name>
+    <message>
+        <source>Volume</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
